@@ -19,6 +19,9 @@ from yplib.db import *
 
 # 有关 邮件 操作的包
 from yplib.mail import *
+from yplib.mail_html import *
+# 生成 markdown 的文本
+from yplib.markdown import *
 
 # 临时添加的工具类
 from yplib.temp import *
